@@ -26,7 +26,7 @@ class NephoStackController(base.NephoBaseController):
             (['cloudlet'], dict(help=argparse.SUPPRESS, nargs='?')),
             (['blueprint'], dict(help=argparse.SUPPRESS, nargs='?')),
             (['--save', '-s'], dict(help=argparse.SUPPRESS, action='store_true')),
-            (['--name', '-n'], dict(help='custom stack name (aws only)', default=None)),
+            (['--name', '-n'], dict(help='custom stack name', default=None)),
             (['--develop', '-d'], dict(help='development mode (vagrant only)', action='store_true')),
             (['--params', '-p'], dict(help=argparse.SUPPRESS, nargs='*', action='append')),
         ]
@@ -34,6 +34,7 @@ class NephoStackController(base.NephoBaseController):
     def _setup(self, app):
         super(base.NephoBaseController, self)._setup(app)
         self.cloudletManager = cloudlet.CloudletManager(self.app)
+        self.paramsManager   = parameter.ParamsManager(self.app)
 
     @controller.expose(help='Show the context for a stack from a blueprint and configs')
     def show_context(self):
@@ -94,10 +95,10 @@ class NephoStackController(base.NephoBaseController):
     def create(self):
         if self.app.cloudlet_name is None or self.app.blueprint_name is None:
             print dedent("""\
-                Usage: nepho stack create <cloudlet> <blueprint> [-n/--name <stack name] [-s/--save] [-p/--params <param>]
+                Usage: nepho stack create <cloudlet> <blueprint> [-n/--name <stack name>] [-s/--save] [-p/--params <param>]
 
                 -n, --name <stack name>
-                  [AWS ONLY] A custom name for your stack rather than nepho-<cloudlet>-<blueprint>.
+                  A custom name for your stack rather than nepho-<cloudlet>-<blueprint>.
                   When using this option you must specify name for other stack actions such as
                   connect, destroy, and status or they will not know which stack to act upon.
                 -s, --save
@@ -111,14 +112,25 @@ class NephoStackController(base.NephoBaseController):
                   prompt for it.
 
                 Examples:
-                  nepho stack create my-app development --params AwsAvailZone1=us-east-1a
-                  nepho stack create my-app development -s -p Foo=True Bar=False -p Test=Passed""")
+                  nepho stack create my-app development --name foostack --params AZ1=us-east-1a
+                  nepho stack create my-app development -s -p Foo=True -p Bar=False""")
             exit(1)
         else:
             scope.print_scope(self)
 
         s = self._assemble_scenario()
-        s.provider.deploy(self.app)
+        s.provider.create(self.app)
+
+    @controller.expose(help='Update a running stack', aliases=['provision'])
+    def update(self):
+        if self.app.cloudlet_name is None or self.app.blueprint_name is None:
+            print "Usage: nepho stack update <cloudlet> <blueprint> [-n/--name <stack name>]"
+            exit(1)
+        else:
+            scope.print_scope(self)
+
+        s = self._assemble_scenario()
+        s.provider.update(self.app)
 
     @controller.expose(help='Check on the status of a stack.')
     def status(self):
@@ -145,7 +157,7 @@ class NephoStackController(base.NephoBaseController):
 
         s.provider.access(self.app)
 
-    @controller.expose(help='Destroy a stack from a blueprint', aliases=['delete', 'down'])
+    @controller.expose(help='Destroy a stack from a blueprint', aliases=['delete', 'down', 'remove'])
     def destroy(self):
         if self.app.cloudlet_name is None or self.app.blueprint_name is None:
             print "Usage: nepho stack destroy <cloudlet> <blueprint> [-n/--name <stack name]"
@@ -202,7 +214,7 @@ class NephoStackController(base.NephoBaseController):
     def _assemble_scenario(self):
         """Helper method to create a suitable scenario from the command line options."""
 
-        stored_params = parameter.ParamsManager(self)
+        stored_params = self.paramsManager
         user_params = self._parse_user_params()
         bprint = self._load_blueprint()
         if self.app.pargs.name is not None:
